@@ -1,22 +1,7 @@
-// -*- indent-tabs-mode:nil -*-
-// vim: set ts=4 sts=4 sw=4 et:
 /* This file is part of the KDE project
-   Copyright (C) 2003 Alexander Kellett <lypanov@kde.org>
+   SPDX-FileCopyrightText: 2003 Alexander Kellett <lypanov@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License version 2 or at your option version 3 as published by
-   the Free Software Foundation.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only
 */
 
 #include "faviconupdater.h"
@@ -84,7 +69,11 @@ void FavIconUpdater::downloadIconUsingWebBrowser(const KBookmark &bk, const QStr
         part->setProperty("javaEnabled", QVariant(false));
         part->setProperty("autoloadImages", QVariant(false));
         KParts::NavigationExtension *ext = KParts::NavigationExtension::childObject(part);
-        Q_ASSERT(ext);
+
+        if (!ext) {
+            Q_EMIT done(false, i18n("No browser component found"));
+            return;
+        }
 
         connect(ext, &KParts::NavigationExtension::setIconUrl, this, &FavIconUpdater::setIconUrl);
         m_part = part;
@@ -137,48 +126,11 @@ FavIconWebGrabber::FavIconWebGrabber(KParts::ReadOnlyPart *part, const QUrl &url
     //  connect(part, SIGNAL(result(KIO::Job*job)),
     //          this, SLOT(slotCompleted()));
     connect(part, &KParts::ReadOnlyPart::canceled, this, &FavIconWebGrabber::slotCanceled);
-    // clang-format off
-    connect(part, SIGNAL(completed(bool)), this, SLOT(slotCompleted()));
-    // clang-format on
-
-    // the use of KIO rather than directly using KHTML is to allow silently abort on error
-    // TODO: an alternative would be to derive from KHTMLPart and reimplement showError(KJob*).
-
-    // qCDebug(KEDITBOOKMARKS_LOG) << "starting KIO::get() on" << m_url;
-    KIO::Job *job = KIO::get(m_url, KIO::NoReload, KIO::HideProgressInfo);
-    job->addMetaData(QStringLiteral("cookies"), QStringLiteral("none"));
-    job->addMetaData(QStringLiteral("errorPage"), QStringLiteral("false"));
-    connect(job, &KJob::result, this, &FavIconWebGrabber::slotFinished);
-    // clang-format off
-    connect(job, SIGNAL(mimetype(KIO::Job*,QString)), this, SLOT(slotMimetype(KIO::Job*,QString)));
-    // clang-format on
-}
-
-void FavIconWebGrabber::slotMimetype(KIO::Job *job, const QString &type)
-{
-    Q_ASSERT(!job->error()); // can't be set already, surely?
-
-    KIO::SimpleJob *sjob = static_cast<KIO::SimpleJob *>(job);
-    m_url = sjob->url(); // allow for redirection
-    sjob->putOnHold();
-
-    // QString typeLocal = typeUncopied; // local copy
-    qCDebug(KEDITBOOKMARKS_LOG) << "slotMimetype " << type << "calling openUrl on" << m_url;
-    // TODO - what to do if typeLocal is not text/html ??
+    connect(part, &KParts::ReadOnlyPart::completed, this, &FavIconWebGrabber::slotCompleted);
 
     m_part->openUrl(m_url);
 }
 
-void FavIconWebGrabber::slotFinished(KJob *job)
-{
-    if (job->error()) {
-        qCDebug(KEDITBOOKMARKS_LOG) << job->errorString();
-        Q_EMIT done(false, job->errorString());
-        return;
-    }
-    // On success mimetype was emitted, so no need to do anything.
-}
-
 void FavIconWebGrabber::slotCompleted()
 {
     qCDebug(KEDITBOOKMARKS_LOG);
